==> tdm_2.0.0.tar.gz: tdm/R/all.Amianhinfusionss.R <==
all.Amianhinfusionss<-function(){
     cat("\n")                                                                      
     cat("-----------------------------------------------------------------------\n")
     cat("    --Aminophylline anhydrous iv infusion input data information--     \n")
     note_for_Theinfusionss_input()
     cat("-----------------------------------------------------------------------\n")                                                            
     cat("\n")
     note_for_close_window()
     AmianhinfusionSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","DL (mg)","tinf (hr)","R (mg/hr)","ts (hr)","c (mg/L)"),value=c(0))                                                                                                          
     AmianhinfusionSSpar<-edit(AmianhinfusionSSpar)                                                                                                                                                                                                             
     AmianhinfusionSSpar<-ycheck(AmianhinfusionSSpar)     
     cat("\n")
     Amianhinfusion.ss(AmianhinfusionSSpar[10,2],AmianhinfusionSSpar[9,2],AmianhinfusionSSpar[3,2],AmianhinfusionSSpar[2,2],AmianhinfusionSSpar[5,2],AmianhinfusionSSpar[1,2],AmianhinfusionSSpar[4,2],AmianhinfusionSSpar[6,2],AmianhinfusionSSpar[8,2],AmianhinfusionSSpar[7,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("-----------------------------------------------------------------------\n")
     cat("   --Aminophylline anhydrous iv infusion output data information--     \n")
     note_for_Theinfusionss_output()
     cat("-----------------------------------------------------------------------\n")
     show(samplesStats("*"))                                                                                                                                                                                                            
     cat("\n")
     C<-Theinfusioncpr(0.85,AmianhinfusionSSpar[6,2],AmianhinfusionSSpar[8,2],AmianhinfusionSSpar[9,2],AmianhinfusionSSpar[7,2])
     sim<-matrix(C[1,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cm_pr (mg/L)")    
     coutput1<-coutput 
     show(coutput)
     C<-0.85*AmianhinfusionSSpar[8,2]/(samplesStats("cl"))
     sim<-matrix(C[1,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")  
     coutput2<-coutput   
     show(coutput)
     cat("\n")   
     Amianhinfusion.more()          
}

==> tdm_2.2.4.tar.gz: tdm/R/all.Amianhinfusionss.R <==
all.Amianhinfusionss<-function(){
     cat("\n")                                                                      
     cat("-----------------------------------------------------------------------\n")
     cat("    --Aminophylline anhydrous iv infusion input data information--     \n")
     note_for_Theinfusionss_input()
     cat("-----------------------------------------------------------------------\n")                                                            
     cat("\n")
     note_for_close_window()
     AmianhinfusionSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","DL (mg)","tinf (hr)","R (mg/hr)","ts (hr)","c (mg/L)"),value=c(0))                                                                                                          
     AmianhinfusionSSpar<-edit(AmianhinfusionSSpar)                                                                                                                                                                                                             
##     AmianhinfusionSSpar<-ycheck(AmianhinfusionSSpar)     
     cat("\n")
     Amianhinfusion.ss(AmianhinfusionSSpar[10,2],AmianhinfusionSSpar[9,2],AmianhinfusionSSpar[3,2],AmianhinfusionSSpar[2,2],AmianhinfusionSSpar[5,2],AmianhinfusionSSpar[1,2],AmianhinfusionSSpar[4,2],AmianhinfusionSSpar[6,2],AmianhinfusionSSpar[8,2],AmianhinfusionSSpar[7,2])
     note_for_convergence_plots()
     convergence_plots_sep()
     cat("-----------------------------------------------------------------------\n")
     cat("   --Aminophylline anhydrous iv infusion output data information--     \n")
     note_for_Theinfusionss_output()
     cat("-----------------------------------------------------------------------\n")
     show(samplesStats("*"))                                                                                                                                                                                                            
     cat("\n")
     C<-Theinfusioncpr(0.85,AmianhinfusionSSpar[6,2],AmianhinfusionSSpar[8,2],AmianhinfusionSSpar[9,2],AmianhinfusionSSpar[7,2])
     sim<-matrix(C[1,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Cm_pr (mg/L)")    
     coutput1<-coutput 
     show(coutput)
     C<-0.85*AmianhinfusionSSpar[8,2]/(samplesStats("cl"))
     sim<-matrix(C[1,1])
     coutput<-data.frame(sim)
     colnames(coutput)<-list("Ctss_pr (mg/L)")  
     coutput2<-coutput   
     show(coutput)
     cat("\n")   
     Amianhinfusion.more()          
}
